@@ -247,13 +247,20 @@ require_once(ABSPATH . 'wp-admin/admin-header.php');
 ?>
 
 <div class="wrap">
-<h1><?php echo esc_html( $title ); if ( current_user_can('install_themes') ) { ?> <a href="theme-install.php" class="page-title-action"><?php echo esc_html_x('Add New', 'theme'); ?></a><?php }
+<h1 class="wp-heading-inline"><?php echo esc_html( $title ); ?></h1>
+
+<?php if ( current_user_can( 'install_themes' ) ) : ?>
+	<a href="theme-install.php" class="page-title-action"><?php echo esc_html_x( 'Add New', 'theme' ); ?></a>
+<?php endif; ?>
+
+<?php
 if ( isset( $_REQUEST['s'] ) && strlen( $_REQUEST['s'] ) ) {
 	/* translators: %s: search keywords */
 	printf( '<span class="subtitle">' . __( 'Search results for &#8220;%s&#8221;' ) . '</span>', esc_html( $s ) );
 }
 ?>
-</h1>
+
+<hr class="wp-header-end">
 
 <?php
 if ( isset( $_GET['enabled'] ) ) {
