@@ -122,7 +122,7 @@ case 'promote':
 			wp_die(__('Sorry, you are not allowed to edit this user.'));
 		// The new role of the current user must also have the promote_users cap or be a multisite super admin
 		if ( $id == $current_user->ID && ! $wp_roles->role_objects[ $role ]->has_cap('promote_users')
-			&& ! ( is_multisite() && is_super_admin() ) ) {
+			&& ! ( is_multisite() && current_user_can( 'manage_network_users' ) ) ) {
 				$update = 'err_admin_role';
 				continue;
 		}
@@ -321,10 +321,6 @@ case 'doremove':
 	$update = 'remove';
  	foreach ( $userids as $id ) {
 		$id = (int) $id;
-		if ( $id == $current_user->ID && !is_super_admin() ) {
-			$update = 'err_admin_remove';
-			continue;
-		}
 		if ( !current_user_can('remove_user', $id) ) {
 			$update = 'err_admin_remove';
 			continue;
@@ -377,10 +373,7 @@ case 'remove':
  	foreach ( $userids as $id ) {
 		$id = (int) $id;
  		$user = get_userdata( $id );
-		if ( $id == $current_user->ID && !is_super_admin() ) {
-			/* translators: 1: user id, 2: user login */
-			echo "<li>" . sprintf(__('ID #%1$s: %2$s <strong>The current user will not be removed.</strong>'), $id, $user->user_login) . "</li>\n";
-		} elseif ( !current_user_can('remove_user', $id) ) {
+		if ( ! current_user_can( 'remove_user', $id ) ) {
 			/* translators: 1: user id, 2: user login */
 			echo "<li>" . sprintf(__('ID #%1$s: %2$s <strong>Sorry, you are not allowed to remove this user.</strong>'), $id, $user->user_login) . "</li>\n";
 		} else {
@@ -491,9 +484,11 @@ if ( ! empty($messages) ) {
 } ?>
 
 <div class="wrap">
-<h1>
-<?php
+<h1 class="wp-heading-inline"><?php
 echo esc_html( $title );
+?></h1>
+
+<?php
 if ( current_user_can( 'create_users' ) ) { ?>
 	<a href="<?php echo admin_url( 'user-new.php' ); ?>" class="page-title-action"><?php echo esc_html_x( 'Add New', 'user' ); ?></a>
 <?php } elseif ( is_multisite() && current_user_can( 'promote_users' ) ) { ?>
@@ -505,7 +500,8 @@ if ( strlen( $usersearch ) ) {
 	printf( '<span class="subtitle">' . __( 'Search results for &#8220;%s&#8221;' ) . '</span>', esc_html( $usersearch ) );
 }
 ?>
-</h1>
+
+<hr class="wp-header-end">
 
 <?php $wp_list_table->views(); ?>
 
@@ -513,6 +509,10 @@ if ( strlen( $usersearch ) ) {
 
 <?php $wp_list_table->search_box( __( 'Search Users' ), 'user' ); ?>
 
+<?php if ( ! empty( $_REQUEST['role'] ) ) { ?>
+<input type="hidden" name="role" value="<?php echo esc_attr( $_REQUEST['role'] ); ?>" />
+<?php } ?>
+
 <?php $wp_list_table->display(); ?>
 </form>
 
