@@ -623,8 +623,12 @@ Manage = MediaFrame.extend({
 		this.$body = $( document.body );
 		this.$window = $( window );
 		this.$adminBar = $( '#wpadminbar' );
+		// Store the Add New button for later reuse in wp.media.view.UploaderInline.
+		this.$uploaderToggler = $( '.page-title-action' )
+			.attr( 'aria-expanded', 'false' )
+			.on( 'click', _.bind( this.addNewClickHandler, this ) );
+
 		this.$window.on( 'scroll resize', _.debounce( _.bind( this.fixPosition, this ), 15 ) );
-		$( document ).on( 'click', '.page-title-action', _.bind( this.addNewClickHandler, this ) );
 
 		// Ensure core and media grid view UI is enabled.
 		this.$el.addClass('wp-core-ui');
@@ -774,6 +778,10 @@ Manage = MediaFrame.extend({
 	addNewClickHandler: function( event ) {
 		event.preventDefault();
 		this.trigger( 'toggle:upload:attachment' );
+
+		if ( this.uploader ) {
+			this.uploader.refresh();
+		}
 	},
 
 	/**
@@ -840,6 +848,9 @@ Manage = MediaFrame.extend({
 	startHistory: function() {
 		// Verify pushState support and activate
 		if ( window.history && window.history.pushState ) {
+			if ( Backbone.History.started ) {
+				Backbone.history.stop();
+			}
 			Backbone.history.start( {
 				root: window._wpMediaGridSettings.adminUrl,
 				pushState: true
